==> wellmap-3.2.0.tar.gz: wellmap-3.2.0/CHANGELOG.md <==
# Versions

Wellmap uses [semantic versioning](https://semver.org/).  Briefly, this means 
that minor version upgrades (e.g. 1.1 to 1.2) will never break any existing 
code, while major version upgrades (e.g. 1.1 to 2.0) might.

<!--next-version-placeholder-->

## v3.2.0 (2021-11-09)
### Feature
* Pick colors based on well coordinates ([`90a25a1`](https://github.com/kalekundert/wellmap/commit/90a25a17455b2b53d973b7a3e867be9943b32bdd))

## v3.1.1 (2021-10-11)
### Fix
* Better error checking ([`eea82a3`](https://github.com/kalekundert/wellmap/commit/eea82a394ae20789731d0068ce096f7cfb6a483d))

## v3.1.0 (2021-10-07)
### Feature
* Allow included layouts to be shifted ([`2ad8b59`](https://github.com/kalekundert/wellmap/commit/2ad8b59bc6cae04b9a83645959bee30fdf668aa2))

### Documentation
* Fix typo ([`5139943`](https://github.com/kalekundert/wellmap/commit/51399430fd378d0863caeb9052fdc0b20f87f71b))

## v3.0.1 (2021-10-01)
### Fix
* Allow multiple patterns to define the same well ([`d0d852c`](https://github.com/kalekundert/wellmap/commit/d0d852c6fcffc47ec063ffaab163fe0dbcdff13b))

### Documentation
* Add link the semantic versioning website ([`eb2f5f2`](https://github.com/kalekundert/wellmap/commit/eb2f5f23d1847c60a9f037e312a030dad4552b30))
* Include the change log in the online docs ([`727f03f`](https://github.com/kalekundert/wellmap/commit/727f03fdfc255dc133a6198f96c20569ee9f386f))
* Revise manuscript after peer review ([`0823802`](https://github.com/kalekundert/wellmap/commit/08238027018c3afddd0bad5b2d4339800329b8d6))
* Briefly describe each alternative sfotware ([`336b47a`](https://github.com/kalekundert/wellmap/commit/336b47a1267589bce760f36da832d4aaf60258bd))

## v3.0.0 (2021-04-11)
### Feature
* Simplify the *extras* argument ([`7558f7a`](https://github.com/kalekundert/wellmap/commit/7558f7ad18917fc3ef9beef60921b7fbe94ff0a3))

### Breaking
* Scipts using the *extras* argument will need to be corrected.  ([`7558f7a`](https://github.com/kalekundert/wellmap/commit/7558f7ad18917fc3ef9beef60921b7fbe94ff0a3))

### Documentation
* Fix the Bradford assay example ([`6e06004`](https://github.com/kalekundert/wellmap/commit/6e060040cb40d2611866c2e38d88f74dfadb50a3))

## v2.1.0 (2021-01-13)
### Feature
* Teach wellmap how to print layouts ([`2e1cfe4`](https://github.com/kalekundert/wellmap/commit/2e1cfe4ffb06b69a21a61037b926f60d8175a496))

### Documentation
* Add an "R API" section ([`4bea19a`](https://github.com/kalekundert/wellmap/commit/4bea19a07ffcd606f9a0a272c8708001a3a3701b))
* Consolidate the table in the pattern section ([`4588a86`](https://github.com/kalekundert/wellmap/commit/4588a864fa9541b98e321f95bb21bdcd1ed99d2c))
* Reformat manuscript for BMC Res Notes ([`b689d26`](https://github.com/kalekundert/wellmap/commit/b689d263e306194ed48427ca0d3e69b4212c1736))
* Tweak wording ([`f7ece3a`](https://github.com/kalekundert/wellmap/commit/f7ece3a36aad59ff3796673cb5c459a89bc730ec))
* Consistently use lower-case for "python" ([`b850377`](https://github.com/kalekundert/wellmap/commit/b850377b1d655d7a0a63ab62210a670146fa369d))
* Translate the "Basic usage" tutorial for R ([`fce3931`](https://github.com/kalekundert/wellmap/commit/fce39310e808b133d92367a7677d925683f77ef6))
* Tweak manuscript ([`7469ae7`](https://github.com/kalekundert/wellmap/commit/7469ae7a334bc19d7209dd1f621a7b68204bd8d8))

==> wellmap-3.4.0.tar.gz: wellmap-3.4.0/CHANGELOG.md <==
# Versions

Wellmap uses [semantic versioning](https://semver.org/).  Briefly, this means 
that minor version upgrades (e.g. 1.1 to 1.2) will never break any existing 
code, while major version upgrades (e.g. 1.1 to 2.0) might.

<!--next-version-placeholder-->

## v3.4.0 (2022-05-08)
### Feature
* Add hyphen range syntax ([`eaf2c73`](https://github.com/kalekundert/wellmap/commit/eaf2c73520881bda7b28ea495bcc044d8b7fad88))

## v3.3.1 (2022-03-26)
### Fix
* Don't drop nans too aggressively ([`a001c8f`](https://github.com/kalekundert/wellmap/commit/a001c8f297d85b5ca5986d8569c29197f9d4bc34))

## v3.3.0 (2022-01-31)
### Feature
* Allow `show(attrs=...)` to be a string ([`0572a61`](https://github.com/kalekundert/wellmap/commit/0572a610de3e1559e4029e0bb7c505e2a07d7ae9))

## v3.2.1 (2021-11-10)
### Fix
* Correct color concave well groups ([`04015bf`](https://github.com/kalekundert/wellmap/commit/04015bf5d76377ccb53eabd5f0a0393137f267de))

## v3.2.0 (2021-11-09)
### Feature
* Pick colors based on well coordinates ([`90a25a1`](https://github.com/kalekundert/wellmap/commit/90a25a17455b2b53d973b7a3e867be9943b32bdd))

## v3.1.1 (2021-10-11)
### Fix
* Better error checking ([`eea82a3`](https://github.com/kalekundert/wellmap/commit/eea82a394ae20789731d0068ce096f7cfb6a483d))

## v3.1.0 (2021-10-07)
### Feature
* Allow included layouts to be shifted ([`2ad8b59`](https://github.com/kalekundert/wellmap/commit/2ad8b59bc6cae04b9a83645959bee30fdf668aa2))

### Documentation
* Fix typo ([`5139943`](https://github.com/kalekundert/wellmap/commit/51399430fd378d0863caeb9052fdc0b20f87f71b))

## v3.0.1 (2021-10-01)
### Fix
* Allow multiple patterns to define the same well ([`d0d852c`](https://github.com/kalekundert/wellmap/commit/d0d852c6fcffc47ec063ffaab163fe0dbcdff13b))

### Documentation
* Add link the semantic versioning website ([`eb2f5f2`](https://github.com/kalekundert/wellmap/commit/eb2f5f23d1847c60a9f037e312a030dad4552b30))
* Include the change log in the online docs ([`727f03f`](https://github.com/kalekundert/wellmap/commit/727f03fdfc255dc133a6198f96c20569ee9f386f))
* Revise manuscript after peer review ([`0823802`](https://github.com/kalekundert/wellmap/commit/08238027018c3afddd0bad5b2d4339800329b8d6))
* Briefly describe each alternative sfotware ([`336b47a`](https://github.com/kalekundert/wellmap/commit/336b47a1267589bce760f36da832d4aaf60258bd))

## v3.0.0 (2021-04-11)
### Feature
* Simplify the *extras* argument ([`7558f7a`](https://github.com/kalekundert/wellmap/commit/7558f7ad18917fc3ef9beef60921b7fbe94ff0a3))

### Breaking
* Scipts using the *extras* argument will need to be corrected.  ([`7558f7a`](https://github.com/kalekundert/wellmap/commit/7558f7ad18917fc3ef9beef60921b7fbe94ff0a3))

### Documentation
* Fix the Bradford assay example ([`6e06004`](https://github.com/kalekundert/wellmap/commit/6e060040cb40d2611866c2e38d88f74dfadb50a3))

## v2.1.0 (2021-01-13)
### Feature
* Teach wellmap how to print layouts ([`2e1cfe4`](https://github.com/kalekundert/wellmap/commit/2e1cfe4ffb06b69a21a61037b926f60d8175a496))

### Documentation
* Add an "R API" section ([`4bea19a`](https://github.com/kalekundert/wellmap/commit/4bea19a07ffcd606f9a0a272c8708001a3a3701b))
* Consolidate the table in the pattern section ([`4588a86`](https://github.com/kalekundert/wellmap/commit/4588a864fa9541b98e321f95bb21bdcd1ed99d2c))
* Reformat manuscript for BMC Res Notes ([`b689d26`](https://github.com/kalekundert/wellmap/commit/b689d263e306194ed48427ca0d3e69b4212c1736))
* Tweak wording ([`f7ece3a`](https://github.com/kalekundert/wellmap/commit/f7ece3a36aad59ff3796673cb5c459a89bc730ec))
* Consistently use lower-case for "python" ([`b850377`](https://github.com/kalekundert/wellmap/commit/b850377b1d655d7a0a63ab62210a670146fa369d))
* Translate the "Basic usage" tutorial for R ([`fce3931`](https://github.com/kalekundert/wellmap/commit/fce39310e808b133d92367a7677d925683f77ef6))
* Tweak manuscript ([`7469ae7`](https://github.com/kalekundert/wellmap/commit/7469ae7a334bc19d7209dd1f621a7b68204bd8d8))
